OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Σφάλμα κατά την ανάλυση του αρχείου καταγραφής",
    "No server logs" : "Δεν υπάρχουν αρχεία καταγραφής εξυπηρετητή",
    "One or more entries are hidden by the log level filter" : "Μια ή περισσότερες καταχωρήσεις αποκρύφθηκαν από το φίλτρο επιπέδου του αρχείου καταγραφής",
    "Everything is working fine" : "Όλα λειτουργούν καλά",
    "Log levels" : "Επίπεδα αρχείου καταγραφής",
    "Log content" : "Περιεχόμενα αρχείου καταγραφής",
    "Live update" : "Ενημέρωση σε πραγματικό χρόνο",
    "Download logs" : "Αρχείο Καταγραφής Λήψεων",
    "Logging" : "Καταγραφή",
    "Log Reader" : "Αναγνώστης Καταγραφών",
    "Cased by " : "Δημιουργήθηκε απο"
},
"nplurals=2; plural=(n != 1);");
